# US2016101909A1
# US 10,194,689

# http://patft.uspto.gov/netacgi/nph-Parser?Sect1=PTO2&Sect2=HITOFF&p=1&u=%2Fnetahtml%2FPTO%2Fsearch-adv.htm&r=1&f=G&l=50&d=PTXT&S1=10194689.PN.&OS=pn/10194689&RS=PN/10194689
# http://pdfpiw.uspto.gov/.piw?PageNum=0&docid=10194689&IDKey=F4A9B9E3F09E%0D%0A&HomeUrl=http%3A%2F%2Fpatft.uspto.gov%2Fnetacgi%2Fnph-Parser%3FSect1%3DPTO2%2526Sect2%3DHITOFF%2526p%3D1%2526u%3D%25252Fnetahtml%25252FPTO%25252Fsearch-adv.htm%2526r%3D1%2526f%3DG%2526l%3D50%2526d%3DPTXT%2526S1%3D10194689.PN.%2526OS%3Dpn%2F10194689%2526RS%3DPN%2F10194689

# Identisches URL format
# http://pimg-fpiw.uspto.gov/fdd/89/946/101/0.pdf
# http://pdfpiw.uspto.gov/fdd/89/946/101/0.pdf

# http://pdfpiw.uspto.gov/89/946/101/1.pdf
# http://pdfpiw.uspto.gov/89/946/101/5.pdf


# How can I link to a particular patent?
# -- http://patft.uspto.gov/netahtml/PTO/help/helpfaq.htm#single
# A special shortened URL format:    http://patft.uspto.gov/netacgi/nph-Parser?patentnumber=5123456

# Where the patent number "5123456" may be replaced by any valid patent number within the database,
# has been established to enable users to more easily construct a URL for bookmarking or linking to
# the full-text of a single granted patent. To simplify this process even further, the patent grant
# search process has been modified such that when a search results in a single hit, the user is
# taken directly to the full-text display for that patent, rather than to a hit list containing only
# the single patent.


# Direct Document Access without Searching
# -- http://patft.uspto.gov/netahtml/PTO/help/status.htm#URL

## To Full-Page Images

# US 10,194,689
# http://pdfpiw.uspto.gov/.piw?Docid=0nnnnnnn&idkey=NONE
# http://pdfpiw.uspto.gov/.piw?Docid=10194689&idkey=NONE
# http://pdfpiw.uspto.gov/.piw?PageNum=0&docid=10194689&IDKey=F4A9B1EBF09E%0D%0A&HomeUrl=http%3A%2F%2Fpdfpiw.uspto.gov%2F

# All pages
# http://pdfpiw.uspto.gov/.piw?docid=10194689&pagenum=0
# http://pdfpiw.uspto.gov/fdd/89/946/101/0.pdf


## To the Full-Text of a Particular Patent



# US 2016 101909 A1

# http://pdfaiw.uspto.gov/.aiw?Docid=20060000000&idkey=NONE
# http://pdfaiw.uspto.gov/.aiw?Docid=20160101909&idkey=NONE
# http://pdfaiw.uspto.gov/.aiw?docid=20160101909&pagenum=0

# http://pimg-faiw.uspto.gov/fdd/09/2016/19/010/0.pdf
# http://pdfaiw.uspto.gov/fdd/09/2016/19/010/0.pdf

# http://localhost:6543/api/pdf/US2016101909A1



WIPO
http://www.wipo.int/patentscope/search/en/WO2012153305


WO2018234963
https://patentscope.wipo.int/search/en/detail.jsf?docId=WO2018234963&tab=PCTDOCUMENTS&maxRec=1000
https://patentscope.wipo.int/search/docs2/pct/WO2018234963/pdf/yGWcT9bfsH9wQ7zSrfkuIVFakOEoKkOkGNzfOFZlIYG1EVGhzfoy0tv2pwZ8KIf1Gz3syVTYCfUqn0bcPvaIy0NGKXGtvLu5GDHz6uy-UPA8ojQF9rJiBoeZH0JfnbD3?docId=id00000045393967&psAuth=ZE_KJI9wVgdzFAdAijbN4uGONFlVMTPdsGePOh82aBc

https://patentscope.wipo.int/search/docs2/pct/WO2018234963/pdf/yGWcT9bfsH9wQ7zSrfkuIVFakOEoKkOkGNzfOFZlIYG1EVGhzfoy0tv2pwZ8KIf1Gz3syVTYCfUqn0bcPvaIy0NGKXGtvLu5GDHz6uy-UPA8ojQF9rJiBoeZH0JfnbD3?docId=id00000045393967


https://patentscope.wipo.int/search/docs2/pct/WO2018234593/pdf/yGWcT9bfsH9wQ7zSrfkuIVFakOEoKkOkGNzfOFZlIYG1EVGhzfoy0tv2pwZ8KIf1Gz3syVTYCfUqn0bcPvaIy0NGKXGtvLu5GDHz6uy-UPA8ojQF9rJiBoeZH0JfnbD3?docId=id00000045393967

